==> jruby-stdlib-1.6.7.2-sources.jar: org/jruby/embed/osgi/internal/OSGiBundlesSearcher.java <==
/***** BEGIN LICENSE BLOCK *****
 * Version: CPL 1.0/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Common Public
 * License Version 1.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.eclipse.org/legal/cpl-v10.html
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * Copyright (C) 2002-2011 JRuby Community
 * 
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the CPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the CPL, the GPL or the LGPL.
 ***** END LICENSE BLOCK *****/
package org.jruby.embed.osgi.internal;

import org.jruby.runtime.load.LoadService.AlreadyLoaded;
import org.jruby.runtime.load.LoadService.LoadSearcher;
import org.jruby.runtime.load.LoadService.SearchState;

/**
 * @author hmalphettes
 * 
 * TODO: something nice with this?
 */
public class OSGiBundlesSearcher implements LoadSearcher {

    /* (non-Javadoc)
     * @see org.jruby.runtime.load.LoadService.LoadSearcher#shouldTrySearch(org.jruby.runtime.load.LoadService.SearchState)
     */
    public boolean shouldTrySearch(SearchState state) {
        return false;
    }

    /* (non-Javadoc)
     * @see org.jruby.runtime.load.LoadService.LoadSearcher#trySearch(org.jruby.runtime.load.LoadService.SearchState)
     */
    public void trySearch(SearchState state) throws AlreadyLoaded {
        
    }

}

==> jruby-stdlib-1.7.3-sources.jar: org/jruby/embed/osgi/internal/OSGiBundlesSearcher.java <==
/***** BEGIN LICENSE BLOCK *****
 * Version: EPL 1.0/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Common Public
 * License Version 1.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.eclipse.org/legal/cpl-v10.html
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * Copyright (C) 2002-2011 JRuby Community
 * 
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the EPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the EPL, the GPL or the LGPL.
 ***** END LICENSE BLOCK *****/
package org.jruby.embed.osgi.internal;

import org.jruby.runtime.load.LoadService.LoadSearcher;
import org.jruby.runtime.load.LoadService.SearchState;

/**
 * @author hmalphettes
 * 
 * TODO: something nice with this?
 */
public class OSGiBundlesSearcher implements LoadSearcher {

    /* (non-Javadoc)
     * @see org.jruby.runtime.load.LoadService.LoadSearcher#shouldTrySearch(org.jruby.runtime.load.LoadService.SearchState)
     */
    public boolean shouldTrySearch(SearchState state) {
        return false;
    }

    /* (non-Javadoc)
     * @see org.jruby.runtime.load.LoadService.LoadSearcher#trySearch(org.jruby.runtime.load.LoadService.SearchState)
     */
    public boolean trySearch(SearchState state) {
        return true;
    }

}
